
From: Kevin Corry <kevcorry@us.ibm.com>

Clarify the comment regarding the "next" field in struct dm_target_spec.  The
"next" field has different behavior if you're performing a DM_TABLE_STATUS
command than it does if you're performing a DM_TABLE_LOAD command.

See populate_table() and retrieve_status() in drivers/md/dm-ioctl.c for more
details on how this field is used.


---

 25-akpm/include/linux/dm-ioctl.h |   10 ++++++++--
 1 files changed, 8 insertions(+), 2 deletions(-)

diff -puN include/linux/dm-ioctl.h~dm-clarify-a-comment include/linux/dm-ioctl.h
--- 25/include/linux/dm-ioctl.h~dm-clarify-a-comment	Mon Apr 12 13:48:53 2004
+++ 25-akpm/include/linux/dm-ioctl.h	Mon Apr 12 13:48:53 2004
@@ -129,8 +129,14 @@ struct dm_target_spec {
 	int32_t status;		/* used when reading from kernel only */
 
 	/*
-	 * Offset in bytes (from the start of this struct) to
-	 * next target_spec.
+	 * Location of the next dm_target_spec.
+	 * - When specifying targets on a DM_TABLE_LOAD command, this value is
+	 *   the number of bytes from the start of the "current" dm_target_spec
+	 *   to the start of the "next" dm_target_spec.
+	 * - When retrieving targets on a DM_TABLE_STATUS command, this value
+	 *   is the number of bytes from the start of the first dm_target_spec
+	 *   (that follows the dm_ioctl struct) to the start of the "next"
+	 *   dm_target_spec.
 	 */
 	uint32_t next;
 

_
